@@ -1,10 +1,9 @@
-import { Injectable } from "@angular/core"
+import { Injectable } from "@angular/core";
 
 @Injectable()
 export class ProfileService {
-    constructor() {
-    }
-    
+    constructor() {}
+
     getProfile() {
         // let headers = new Headers();
         // headers.append('Content-Type', 'application/json');
@@ -15,4 +14,4 @@ export class ProfileService {
         //   .get('/profile', { headers })
         //   .map(res => res.json());
     }
-}
\ No newline at end of file
+}
